==> qtjambi-remoteobjects-jre8-5.15-sources.jar: io/qt/remoteobjects/QRemoteObjectPendingCallWatcher.java <==
package io.qt.remoteobjects;


/**
 * <p>Provides a QObject-based API for watching a QRemoteObjectPendingCall</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcallwatcher.html">QRemoteObjectPendingCallWatcher</a></p>
 */
public class QRemoteObjectPendingCallWatcher extends io.qt.core.QObject
    implements io.qt.remoteobjects.QRemoteObjectPendingCall
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectPendingCallWatcher.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcallwatcher.html#finished">QRemoteObjectPendingCallWatcher::finished(QRemoteObjectPendingCallWatcher*)</a></p>
     */
    public final Signal1<io.qt.remoteobjects.QRemoteObjectPendingCallWatcher> finished = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectPendingCallWatcher(io.qt.remoteobjects.QRemoteObjectPendingCall, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectPendingCallWatcher(io.qt.remoteobjects.QRemoteObjectPendingCall call) {
        this(call, (io.qt.core.QObject)null);
    }
    
    public QRemoteObjectPendingCallWatcher(io.qt.remoteobjects.QRemoteObjectPendingCall call, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, call, parent);
    }
    
    private native static void initialize_native(QRemoteObjectPendingCallWatcher instance, io.qt.remoteobjects.QRemoteObjectPendingCall call, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcall.html#error">QRemoteObjectPendingCall::</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.remoteobjects.QRemoteObjectPendingCall.Error error(){
        return io.qt.remoteobjects.QRemoteObjectPendingCall.Error.resolve(error_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    private native static int error_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcall.html#isFinished">QRemoteObjectPendingCall::isFinished()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isFinished(){
        return isFinished_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native static boolean isFinished_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcall.html#returnValue">QRemoteObjectPendingCall::</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object returnValue(){
        return returnValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native static java.lang.Object returnValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcallwatcher.html#waitForFinished">QRemoteObjectPendingCallWatcher::waitForFinished()</a></p>
     */
    @io.qt.QtUninvokable
    public final void waitForFinished(){
        waitForFinished_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void waitForFinished_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcall.html#waitForFinished">QRemoteObjectPendingCall::</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean waitForFinished(int timeout){
        return waitForFinished_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), timeout);
    }
    
    private native static boolean waitForFinished_native_int(long __this__nativeId, int timeout);
    
    public native static io.qt.remoteobjects.QRemoteObjectPendingCall fromCompletedCall(java.lang.Object returnValue);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRemoteObjectPendingCallWatcher(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-remoteobjects-jre8-5.15.3-sources.jar: io/qt/remoteobjects/QRemoteObjectPendingCallWatcher.java <==
package io.qt.remoteobjects;


/**
 * <p>Provides a QObject-based API for watching a QRemoteObjectPendingCall</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcallwatcher.html">QRemoteObjectPendingCallWatcher</a></p>
 */
public class QRemoteObjectPendingCallWatcher extends io.qt.core.QObject
    implements io.qt.remoteobjects.QRemoteObjectPendingCall
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectPendingCallWatcher.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcallwatcher.html#finished">QRemoteObjectPendingCallWatcher::finished(QRemoteObjectPendingCallWatcher*)</a></p>
     */
    public final Signal1<io.qt.remoteobjects.QRemoteObjectPendingCallWatcher> finished = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectPendingCallWatcher(io.qt.remoteobjects.QRemoteObjectPendingCall, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectPendingCallWatcher(io.qt.remoteobjects.QRemoteObjectPendingCall call) {
        this(call, (io.qt.core.QObject)null);
    }
    
    public QRemoteObjectPendingCallWatcher(io.qt.remoteobjects.QRemoteObjectPendingCall call, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, call, parent);
    }
    
    private native static void initialize_native(QRemoteObjectPendingCallWatcher instance, io.qt.remoteobjects.QRemoteObjectPendingCall call, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcall.html#error">QRemoteObjectPendingCall::error()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.remoteobjects.QRemoteObjectPendingCall.Error error(){
        return io.qt.remoteobjects.QRemoteObjectPendingCall.Error.resolve(error_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    private native static int error_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcall.html#isFinished">QRemoteObjectPendingCall::isFinished()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isFinished(){
        return isFinished_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native static boolean isFinished_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcall.html#returnValue">QRemoteObjectPendingCall::returnValue()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object returnValue(){
        return returnValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native static java.lang.Object returnValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcallwatcher.html#waitForFinished">QRemoteObjectPendingCallWatcher::waitForFinished()</a></p>
     */
    @io.qt.QtUninvokable
    public final void waitForFinished(){
        waitForFinished_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void waitForFinished_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectpendingcall.html#waitForFinished">QRemoteObjectPendingCall::waitForFinished(int)</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean waitForFinished(int timeout){
        return waitForFinished_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), timeout);
    }
    
    private native static boolean waitForFinished_native_int(long __this__nativeId, int timeout);
    
    public native static io.qt.remoteobjects.QRemoteObjectPendingCall fromCompletedCall(java.lang.Object returnValue);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRemoteObjectPendingCallWatcher(QPrivateConstructor p) { super(p); } 
    
}
